Crate limbo_macros

Crate limbo_macros 

Macros

register_extension
Register your extension with ‘core’ by providing the relevant functions

Attribute Macros

scalar
Declare a scalar function for your extension. This requires the name: #[scalar(name = “example”)] of what you wish to call your function with.

Derive Macros

AggregateDerive
Define an aggregate function for your extension by deriving AggregateDerive on a struct that implements the AggFunc trait.
Description
A procedural macro that derives a Description trait for enums. This macro extracts documentation comments (specified with /// Description...) for enum variants and generates an implementation for get_description, which returns the associated description.
VTabModuleDerive
Macro to derive a VTabModule for your extension. This macro will generate the necessary functions to register your module with core. You must implement the VTabModule, VTable, and VTabCursor traits.
VfsDerive